@@ -1,7 +1,7 @@
 # coding=utf-8
 """
-A Great Dane turned Python environment detective
-================================================
+Great Dane turned Python environment detective
+==============================================
 
 A lightweight toolset to easily report your Python environment's package
 versions and hardware resources.
@@ -15,16 +15,29 @@ Werthmüller for ``empymod``, ``emg3d``, and the ``SimPEG`` framework
 ``watermark.py`` from https://github.com/rasbt/watermark.
 """
 
+from scooby.knowledge import (  # noqa
+    get_standard_lib_modules,
+    in_ipykernel,
+    in_ipython,
+    meets_version,
+    version_tuple,
+)
 from scooby.report import Report, get_version
-from scooby.knowledge import (get_standard_lib_modules, in_ipykernel,  # noqa
-                              in_ipython, meets_version, version_tuple)
 from scooby.tracker import TrackedReport, track_imports, untrack_imports
 
-__all__ = ['Report', 'TrackedReport', 'get_standard_lib_modules', 'in_ipython',
-           'in_ipykernel', 'get_version', 'track_imports', 'untrack_imports']
+__all__ = [
+    'Report',
+    'TrackedReport',
+    'get_standard_lib_modules',
+    'in_ipython',
+    'in_ipykernel',
+    'get_version',
+    'track_imports',
+    'untrack_imports',
+]
 
 
 __author__ = 'Dieter Werthmüller & Bane Sullivan'
 __license__ = 'MIT'
 __copyright__ = '2019, Dieter Werthmüller & Bane Sullivan'
-__version__ = '0.5.6'
+__version__ = '0.5.8'
